<?php
/**
 * Oasis.
 *
 * This file adds the Customizer additions to the Oasis Theme.
 *
 * @package Oasis
 * @author  Appfinite
 * @license GPL-2.0-or-later
 * @link    https://www.appfinite.com/
 */

add_action( 'customize_register', 'oasis_customizer_register' );
/**
 * Registers settings and controls with the Customizer.
 *
 * @since 1.0.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function oasis_customizer_register( $wp_customize ) {

	$appearance = genesis_get_config( 'appearance' );

	$wp_customize->add_setting(
		'oasis_link_color',
		array(
			'default'           => $appearance['default-colors']['link'],
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'oasis_link_color',
			array(
				'description' => __( 'Change the color of post info links and button blocks, the hover color of linked titles and menu items, and more.', 'oasis' ),
				'label'       => __( 'Link Color', 'oasis' ),
				'section'     => 'colors',
				'settings'    => 'oasis_link_color',
			)
		)
	);

	$wp_customize->add_setting(
		'oasis_accent_color',
		array(
			'default'           => $appearance['default-colors']['accent'],
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'oasis_accent_color',
			array(
				'description' => __( 'Change the default hover color for button links, menu buttons, and submit buttons. The button block uses the Link Color.', 'oasis' ),
				'label'       => __( 'Accent Color', 'oasis' ),
				'section'     => 'colors',
				'settings'    => 'oasis_accent_color',
			)
		)
	);

	$wp_customize->add_setting(
		'oasis_logo_width',
		array(
			'default'           => 350,
			'sanitize_callback' => 'absint',
		)
	);

	// Add a control for the logo size.
	$wp_customize->add_control(
		'oasis_logo_width',
		array(
			'label'       => __( 'Logo Width', 'oasis' ),
			'description' => __( 'The maximum width of the logo in pixels.', 'oasis' ),
			'priority'    => 9,
			'section'     => 'title_tagline',
			'settings'    => 'oasis_logo_width',
			'type'        => 'number',
			'input_attrs' => array(
				'min' => 100,
			),

		)
	);

}
